@@ -7,6 +7,7 @@ from spacy.tokens import Span, Token, Doc
 
 
 class TokenPolarityOutput(BaseModel):
+    """A data class for the polarity output of a span, notably allows for plotting the output"""
     class Config:
         arbitrary_types_allowed = True
 
@@ -44,6 +45,7 @@ class TokenPolarityOutput(BaseModel):
 
 
 class SpanPolarityOutput(BaseModel):
+    """A data class for the polarity output of a span, notably allows for plotting the output"""
     class Config:
         arbitrary_types_allowed = True
 
@@ -84,6 +86,7 @@ class SpanPolarityOutput(BaseModel):
 
 
 class DocPolarityOutput(BaseModel):
+    """A data class for the polarity output of a doc"""
     class Config:
         arbitrary_types_allowed = True
 
