@@ -80,8 +80,7 @@ def make_intensifier_getter(
             if token.is_upper and token.doc._.is_cap_diff:
                 scalar += C_INCR
             return scalar
-        else:
-            return 0.0
+        return 0.0
 
     return intensifier_scalar_getter
 
@@ -151,13 +150,12 @@ def make_valance_getter(
         if not Span.has_extension("is_cap_diff"):
             Span.set_extension("is_cap_diff", getter=allcap_differential_getter)
         return cap_diff_valence_getter
-    else:
-        return lemma_valence_getter
+    return lemma_valence_getter
 
 
 def make_is_negation_getter(
     negations: Iterable[str], lemmatize: bool = True, lowercase: bool = True
-) -> Callable:
+) -> Callable[[Token], bool]:
     """Creates a token getter which return whether a token is a negation or not.
 
     Args:
@@ -166,7 +164,7 @@ def make_is_negation_getter(
         lowercase (bool, optional): Should it look up in negations using the lowercased word? Defaults to True.
 
     Returns:
-        Callable: [description]
+        Callable[[Token], bool]: A token getter
     """
     t_getter = make_txt_getter(lemmatize, lowercase)
 
@@ -184,8 +182,18 @@ def make_is_contrastive_conj_getter(
     contrastive_conjugations: Iterable[str],
     lemmatize: bool = True,
     lowercase: bool = True,
-) -> Callable:
-    """..."""
+) -> Callable[[Token], bool]:
+    """Creates a token getter for whether a token is a constrastive conjugations
+
+    Args:
+        contrastive_conjugations (Iterable[str]): A list of contrastive conjugations.
+        lemmatize (bool, optional): Should you lemmatize before lookup in the contrastive conjugations list? Defaults to True.
+        lowercase (bool, optional): Should you lowercase before lookup in the contrastive conjugations list? Defaults to True.
+
+    Returns:
+        Callable[[Token], bool]: A token getter
+    """
+
     t_getter = make_txt_getter(lemmatize, lowercase)
 
     def is_contrastive_conj(token: Token) -> bool:
@@ -209,6 +217,7 @@ def make_is_negated_getter(
         is_negation_getter (Optional[Callable[[Token], bool]], optional): A function which given a
             token return if the token is a negation or not. If None it assumes that the the token
             extention "is_negation" is set. If specified overwrites teh extension. Defualts to None.
+
     Returns:
         Callable[[Token], bool]: The getter function
     """
@@ -245,7 +254,7 @@ def make_is_negated_getter(
 
 def make_token_polarity_getter(
     valence_getter: Optional[Callable[[Token], float]] = None,
-    is_negation_getter: Optional[Callable[[Token], bool]] = None,
+    is_negated_getter: Optional[Callable[[Token], bool]] = None,
     intensifier_getter: Optional[Callable[[Token], float]] = None,
     negation_scalar: float = N_SCALAR,
     lookback_intensities: List[float] = [1.0, 0.95, 0.90],
@@ -259,17 +268,17 @@ def make_token_polarity_getter(
         valence_getter (Optional[Callable[[Token], float]]): a function which given a token return the
             valence (sentiment) of the token. If None it assumes that the the token extention "valence"
             is set. If specified it overwrites the extension. Defualts to None.
-        is_negation_getter (Optional[Callable[[Token], bool]], optional): A function which given a
-            token return if the token is a negation or not. If None it assumes that the the token
-            extention "is_negation" is set. If specified it overwrites the extension. Defualts to None.
+        is_negated_getter (Optional[Callable[[Token], bool]], optional): A function which given a
+            token return a boolean indicating whether the token is negated. If None it assumes that the the token
+            extention "is_negated" is set. If specified it overwrites the extension. Defualts to None.
         intensifier_getter (Optional[Callable[[Token], float]], optional): A getter which for a token
             return 0 if it is not an intensifier or its intensifcation value if it is an intensifier.
             E.g. the token 'especially' might have an value of 0.293 which increases or decreases the
             valence of the following word by the specified amount. Defaults to None,
             intensifiers aren't included in the analysis of token valence.
-        negation_scalar (float, optional): [description]. Defaults to the emperically derived constant
+        negation_scalar (float, optional):  Defaults to the emperically derived constant
             -0.74 (Hutto and Gilbert, 2014).
-        lookback_intensities (List[float], optional): How long to look back for negations and intensifiers
+        lookback_intensities (List[float], optional): How long to look back for intensifiers
             (length). Intensities indicate the how much to weight each intensifier. Defaults to
             [1.0, 0.95, 0.90] which is emperically derived (Hutto and Gilbert, 2014).
 
@@ -286,12 +295,10 @@ def make_token_polarity_getter(
             "Token class has no extension 'valence', either set the extension"
             + " or provide the valence_getter."
         )
-    if is_negation_getter:
+    if is_negated_getter:
         Token.set_extension(
             "is_negated",
-            getter=make_is_negated_getter(
-                lookback=lookback, is_negation_getter=is_negation_getter
-            ),
+            getter=is_negated_getter,
             force=True,
         )
     if not Token.has_extension("is_negated"):
@@ -314,7 +321,6 @@ def make_token_polarity_getter(
         valence = token._.valence
 
         start_tok = token.i  # only used if span is returned
-        negated = False
         if valence:
             for start_i in range(1, lookback + 1):
                 # dampen the scalar modifier of preceding words and emoticons
@@ -330,10 +336,9 @@ def make_token_polarity_getter(
                         valence = valence + b
                     else:
                         valence = valence - b
-                    if not negated and prev_token._.is_negation:
-                        valence = valence * negation_scalar
-                        negated = True  # prevent double negations
-                        start_tok = prev_token.i
+            if token._.is_negated:
+                valence = valence * negation_scalar
+
 
         return TokenPolarityOutput(
             polarity=valence, token=token, span=token.doc[start_tok : token.i + 1]
@@ -350,10 +355,9 @@ def normalize(score, alpha=15):
     norm_score = score / math.sqrt((score * score) + alpha)
     if norm_score < -1.0:
         return -1.0
-    elif norm_score > 1.0:
+    if norm_score > 1.0:
         return 1.0
-    else:
-        return norm_score
+    return norm_score
 
 
 def questionmark_amplification(text: str) -> float:
@@ -389,7 +393,7 @@ def but_check(
     sentiment: list,
     before_but_scalar: float = BEFORE_BUT_SCALAR,
     after_but_scalar: float = AFTER_BUT_SCALAR,
-):
+) -> list:
     contains_but = False
     for token in span:
         if token._.is_contrastive_conj:
@@ -431,8 +435,6 @@ def make_span_polarity_getter(
     """Creates a function (getter) which for a span return the aggrated polarities. Including accounting for
     contrastive conjugations (e.g. 'but'), exclamationsmarks and questionmarks.
 
-    Assumed the Token extention "polarity" is set and returns a TokenPolarityOutput.
-
     Args:
         polarity_getter (Optional[Callable[[Token], float]]): A function which given a token return
             the polarity (sentiment) of the token. If None it assumes that the token extension
